@@ -2,12 +2,15 @@ import os
 import importlib
 import logging
 from kaizen.llms.provider import LLMProvider
-from kaizen.helpers.parser import extract_json
+from kaizen.helpers.parser import extract_json, extract_code_from_markdown
+from kaizen.actors.unit_test_runner import UnitTestRunner
 from kaizen.llms.prompts.unit_tests_prompts import (
     UNIT_TEST_SYSTEM_PROMPT,
     UNIT_TEST_PROMPT,
     REVIEW_UNIT_TEST_PROMPT,
+    REVIEW_TEST_CASE_PROMPT,
 )
+from tqdm import tqdm
 
 
 class UnitTestGenerator:
@@ -24,16 +27,21 @@ class UnitTestGenerator:
             "ts": "TypeScriptParser",
             "jsx": "ReactParser",
             "tsx": "ReactTSParser",
+            "rs": "RustParser",
         }
         self.logger = logging.getLogger(__name__)
         self.provider = LLMProvider(system_prompt=UNIT_TEST_SYSTEM_PROMPT)
-        self._create_output_folder()
+        self._create_output_folder(self.output_folder)
 
-    def generate_tests(self, file_path: str, content: str = None):
+    def generate_tests(
+        self, file_path: str, content: str = None, output_path: str = None
+    ):
         """
         file_path: (str) - path of file relative to the root of project.
         content: (str) - File Content
         """
+        if output_path:
+            self.output_folder = output_path
         file_extension = file_path.split(".")[-1]
         if file_extension not in self.supported_languages:
             raise ValueError(f"Unsupported file type: .{file_extension}")
@@ -45,34 +53,59 @@ class UnitTestGenerator:
         parser_class = getattr(parser_module, parser_class_name)
         parser = parser_class()
 
-        # Load content if its none
-        with open(file_path, "r+") as file:
-            content = file.read()
+        if not content:
+            with open(file_path, "r+") as file:
+                content = file.read()
 
         parsed_data = parser.parse(content)
         self.generate_test_files(parsed_data, file_extension, file_path)
         return {}, self.total_usage
 
     def generate_test_files(self, parsed_data, file_extension, file_path):
+        folder_path = "/".join(file_path.split("/")[:-1])
         self.total_usage = self.provider.DEFAULT_USAGE
-        for item in parsed_data:
+        for item in tqdm(parsed_data, desc="Processing Items", unit="item"):
+            print(f"\n{'='*50}")
+            print(f"Processing Item: {item['name']}")
+            print(f"{'='*50}")
+
+            # Step 1: Prepare file name and path
+            print("• Preparing file name and path...")
             test_file_name = f"test_{item['name'].lower()}.{file_extension}"
-            test_file_path = os.path.join(self.output_folder, test_file_name)
+            test_file_path = os.path.join(
+                self.output_folder, folder_path, test_file_name
+            )
+            self._create_output_folder("/".join(test_file_path.split("/")[:-1]))
             item["full_path"] = file_path
+            print(f"  ✓ File will be saved as: {test_file_path}")
+
+            # Step 2: Generate AI tests
+            print("• Generating AI tests...")
             ai_generated_tests, usage = self.generate_ai_tests(
                 item, source_code=item["source"]
             )
             self.total_usage = self.provider.update_usage(self.total_usage, usage)
             tests_json = extract_json(ai_generated_tests)
-            self.logger.info(f"ai generated tests: {ai_generated_tests}")
-            # test_file_path = tests_json["test_file_name"]
-            ai_generated_tests, usage = self.review_ai_generated_tests(
-                item, source_code=item["source"], current_tests=tests_json
+            print(f"  ✓ AI tests generated successfully")
+
+            # Step 3: Review test file
+            print("• Reviewing test file...")
+            test_code, usage = self.review_test_file(
+                test_file_name, tests_json["test_file_content"]
             )
             self.total_usage = self.provider.update_usage(self.total_usage, usage)
-            tests_json = extract_json(ai_generated_tests)
+            test_code = extract_code_from_markdown(test_code)
+            print(f"  ✓ Test file reviewed successfully")
+
+            # Step 4: Write test file
+            print("• Writing test file...")
             with open(test_file_path, "w") as test_file:
-                test_file.write(tests_json["test_file_content"])
+                test_file.write(test_code)
+            print(f"  ✓ Test file written successfully")
+
+            print("\n✓ Item processing complete")
+
+        print("\nAll items processed successfully!")
 
     def generate_ai_tests(self, item, source_code):
         prompt = UNIT_TEST_PROMPT.format(
@@ -95,41 +128,19 @@ class UnitTestGenerator:
         response, usage = self.provider.chat_completion(prompt, model="best")
         return response, usage
 
-    def _create_output_folder(self):
-        os.makedirs(self.output_folder, exist_ok=True)
+    def review_test_file(self, file_name, test_code):
+        file_content_prompt = REVIEW_TEST_CASE_PROMPT.format(
+            FILE_NAME=file_name, CODE=test_code
+        )
+        response, usage = self.provider.chat_completion(
+            file_content_prompt, model="best"
+        )
+        return response, usage
 
+    def _create_output_folder(self, folder_name):
+        os.makedirs(folder_name, exist_ok=True)
 
-if __name__ == "__main__":
-    generator = UnitTestGenerator()
-    code = '''
-class Calculator:
-    def __init__(self):
-        self.result = 0
-
-    def add(self, a, b):
-        """Add two numbers and store the result."""
-        self.result = a + b
-        return self.result
-
-    def subtract(self, a, b):
-        """Subtract b from a and store the result."""
-        self.result = a - b
-        return self.result
-
-    def get_result(self):
-        """Return the last calculated result."""
-        return self.result
-
-def greet(name):
-    """Return a greeting message."""
-    return f"Hello, {name}!"
-
-if __name__ == "__main__":
-    calc = Calculator()
-    print(calc.add(5, 3))  # Should print 8
-    print(calc.subtract(10, 4))  # Should print 6
-    print(calc.get_result())  # Should print 6
-    print(greet("Alice"))  # Should print "Hello, Alice!"
-'''
-    # generator.generate_tests(file_path="sample.py", content=code)  # Replace with the actual file path
-    generator.generate_tests(file_path="kaizen/helpers/output.py")
+    def run_tests(self):
+        runner = UnitTestRunner(self.output_folder)
+        results = runner.discover_and_run_tests()
+        return results
