@@ -7,6 +7,8 @@ from kaizen.helpers.general import retry
 from kaizen.helpers.parser import extract_json
 from litellm import Router
 import logging
+from collections import defaultdict
+
 
 LOGLEVEL = os.environ.get("LOG_LEVEL", "INFO").upper()
 logging.basicConfig(
@@ -27,11 +29,13 @@ class LLMProvider:
         system_prompt: str = BASIC_SYSTEM_PROMPT,
         model_config: Dict[str, Any] = DEFAULT_MODEL_CONFIG,
         default_temperature: float = 0.3,
+        callback_obj="supabase",
     ):
         self.config = ConfigData().get_config_data()
         self.system_prompt = system_prompt
         self.model_config = model_config
         self.default_temperature = default_temperature
+        self.callback_obj = "supabase"
         self.logger = logging.getLogger(
             __name__,
         )
@@ -67,6 +71,19 @@ class LLMProvider:
 
         self.provider = Router(**provider_kwargs)
         self.model = self.models[0]["litellm_params"]["model"]
+        self.model_group_to_name = dict(
+            defaultdict(
+                list,
+                {
+                    item["model_name"]: [
+                        i["litellm_params"]["model"]
+                        for i in self.models
+                        if i["model_name"] == item["model_name"]
+                    ]
+                    for item in self.models
+                },
+            )
+        )
 
     def _setup_redis(self, provider_kwargs: Dict[str, Any]) -> None:
         redis_host = os.environ.get("REDIS_HOST")
@@ -86,8 +103,8 @@ class LLMProvider:
 
     def _setup_observability(self) -> None:
         if self.config["language_model"].get("enable_observability_logging", False):
-            litellm.success_callback = ["supabase"]
-            litellm.failure_callback = ["supabase"]
+            litellm.success_callback = [self.callback_obj]
+            litellm.failure_callback = [self.callback_obj]
 
     def _register_unkown_models(self) -> None:
         for model_data in self.models:
@@ -144,6 +161,24 @@ class LLMProvider:
         response = extract_json(response)
         return response, usage
 
+    @retry(max_attempts=3, delay=1)
+    def chat_completion_with_retry(
+        self,
+        prompt,
+        user: str = None,
+        model="default",
+        custom_model=None,
+        messages=None,
+    ):
+        response, usage = self.chat_completion(
+            prompt=prompt,
+            user=user,
+            model=model,
+            custom_model=custom_model,
+            messages=messages,
+        )
+        return response, usage
+
     def is_inside_token_limit(self, PROMPT: str, percentage: float = 0.8) -> bool:
         # Include system prompt in token calculation
         messages = [
