@@ -10,6 +10,78 @@ from kaizen.llms.prompts.code_review_prompts import (
     CODE_REVIEW_SYSTEM_PROMPT,
 )
 import json
+import fnmatch
+
+sensitive_files = {
+    "Configuration": [
+        ".env",
+        ".config",
+        "config.json",
+        "config.yaml",
+        "config.yml",
+        ".ini",
+        ".toml",
+        "settings.py",
+    ],
+    "Build and Dependency": [
+        "requirements.txt",
+        "Pipfile",
+        "Pipfile.lock",
+        "package.json",
+        "package-lock.json",
+        "yarn.lock",
+        "Gemfile",
+        "Gemfile.lock",
+        "pom.xml",
+        "build.gradle",
+    ],
+    "CI/CD": [
+        ".travis.yml",
+        ".gitlab-ci.yml",
+        "Jenkinsfile",
+        ".circleci/config.yml",
+        ".github/workflows/*.yml",
+    ],
+    "Docker": [
+        "Dockerfile",
+        "docker-compose.yml",
+        ".dockerignore",
+    ],
+    "Version Control": [
+        ".gitignore",
+        ".gitattributes",
+        ".gitmodules",
+    ],
+    "Security": [
+        "security.txt",
+        ".htaccess",
+        "robots.txt",
+    ],
+    "Database": [
+        "*.sql",
+        "schema.rb",
+        "migrations/*.rb",
+        "alembic/versions/*.py",
+    ],
+    "Documentation": [
+        "README.md",
+        "CHANGELOG.md",
+        "LICENSE",
+        "CONTRIBUTING.md",
+    ],
+    "Infrastructure as Code": [
+        "*.tf",  # Terraform
+        "*.hcl",  # Hashicorp Configuration Language
+        "cloudformation.yaml",
+        "*.template",  # AWS CloudFormation
+    ],
+    "Sensitive Data": [
+        "*.pem",
+        "*.key",
+        "*.cer",
+        "*.crt",
+    ],
+}
 
 
 @dataclass
@@ -53,12 +125,14 @@ class CodeReviewer:
         pull_request_files: List[Dict],
         user: Optional[str] = None,
         reeval_response: bool = False,
-        model="default"
+        model="default",
+        custom_prompt="",
     ) -> ReviewOutput:
         prompt = CODE_REVIEW_PROMPT.format(
             PULL_REQUEST_TITLE=pull_request_title,
             PULL_REQUEST_DESC=pull_request_desc,
             CODE_DIFF=parser.patch_to_combined_chunks(diff_text),
+            CUSTOM_PROMPT=custom_prompt,
         )
         self.total_usage = {
             "prompt_tokens": 0,
@@ -77,8 +151,11 @@ class CodeReviewer:
                 pull_request_desc,
                 user,
                 reeval_response,
+                custom_prompt=custom_prompt,
             )
 
+        reviews.extend(self.check_sensetive_files(pull_request_files))
+
         topics = self._merge_topics(reviews)
         prompt_cost, completion_cost = self.provider.get_usage_cost(
             total_usage=self.total_usage
@@ -99,7 +176,9 @@ class CodeReviewer:
     ) -> List[Dict]:
         self.logger.debug("Processing directly from diff")
         custom_model = {"model": self.default_model}
-        resp, usage = self.provider.chat_completion_with_json(prompt, user=user, custom_model=custom_model)
+        resp, usage = self.provider.chat_completion_with_json(
+            prompt, user=user, custom_model=custom_model
+        )
         self.total_usage = self.provider.update_usage(self.total_usage, usage)
         if reeval_response:
             resp = self._reevaluate_response(prompt, resp, user)
@@ -112,6 +191,7 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
+        custom_prompt: str,
     ) -> List[Dict]:
         self.logger.debug("Processing based on files")
         reviews = []
@@ -121,6 +201,7 @@ class CodeReviewer:
             pull_request_desc,
             user,
             reeval_response,
+            custom_prompt,
         ):
             reviews.extend(file_review)
         return reviews
@@ -132,13 +213,14 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
+        custom_prompt: str,
     ) -> Generator[List[Dict], None, None]:
         combined_diff_data = ""
         available_tokens = self.provider.available_tokens(FILE_CODE_REVIEW_PROMPT)
 
         for file in pull_request_files:
             patch_details = file.get("patch")
-            filename = file.get("filename", "")
+            filename = file.get("filename", "").replace(" ", "")
 
             if (
                 filename.split(".")[-1] not in parser.EXCLUDED_FILETYPES
@@ -159,19 +241,20 @@ class CodeReviewer:
                     pull_request_desc,
                     user,
                     reeval_response,
+                    custom_prompt,
                 )
                 combined_diff_data = (
                     f"\n---->\nFile Name: {filename}\nPatch Details: {patch_details}"
                 )
 
-        if combined_diff_data:
-            yield self._process_file_chunk(
-                combined_diff_data,
-                pull_request_title,
-                pull_request_desc,
-                user,
-                reeval_response,
-            )
+        yield self._process_file_chunk(
+            combined_diff_data,
+            pull_request_title,
+            pull_request_desc,
+            user,
+            reeval_response,
+            custom_prompt,
+        )
 
     def _process_file_chunk(
         self,
@@ -180,6 +263,7 @@ class CodeReviewer:
         pull_request_desc: str,
         user: Optional[str],
         reeval_response: bool,
+        custom_prompt: str,
     ) -> List[Dict]:
         if not diff_data:
             return []
@@ -187,9 +271,12 @@ class CodeReviewer:
             PULL_REQUEST_TITLE=pull_request_title,
             PULL_REQUEST_DESC=pull_request_desc,
             FILE_PATCH=diff_data,
+            CUSTOM_PROMPT=custom_prompt,
         )
         custom_model = {"model": self.default_model}
-        resp, usage = self.provider.chat_completion_with_json(prompt, user=user, custom_model=custom_model)
+        resp, usage = self.provider.chat_completion_with_json(
+            prompt, user=user, custom_model=custom_model
+        )
         self.total_usage = self.provider.update_usage(self.total_usage, usage)
 
         if reeval_response:
@@ -218,3 +305,33 @@ class CodeReviewer:
         for review in reviews:
             topics.setdefault(review["topic"], []).append(review)
         return topics
+
+    def check_sensetive_files(self, pull_request_files: list):
+        reviews = []
+
+        for category, patterns in sensitive_files.items():
+            for patch_data in pull_request_files:
+                file_name = patch_data.get("filename", "").replace(" ", "")
+                for pattern in patterns:
+                    if fnmatch.fnmatch(file_name, pattern):
+                        patch = patch_data.get("patch", "")
+                        line = 1
+                        if patch:
+                            line = patch.split(" ")[2].split(",")[0][1:]
+                        reviews.append(
+                            {
+                                "topic": category,
+                                "comment": "Changes made to Sensetive file",
+                                "confidence": "critical",
+                                "reason": f"Changes were made to {file_name}, which needs review",
+                                "solution": "NA",
+                                "fixed_code": "",
+                                "start_line": line,
+                                "end_line": line,
+                                "side": "RIGHT",
+                                "file_name": file_name,
+                                "sentiment": "negative",
+                                "severity_level": 10,
+                            }
+                        )
+        return reviews
